@@ -29,7 +29,7 @@ See `CircuitPython:board` in CircuitPython for more details.
 """
 
 
-__version__ = "6.15.0"
+__version__ = "6.19.0"
 __repo__ = "https://github.com/adafruit/Adafruit_Blinka.git"
 __blinka__ = True
 
@@ -54,6 +54,13 @@ elif board_id == ap_board.PYBOARD:
 elif board_id == ap_board.RASPBERRY_PI_PICO:
     from adafruit_blinka.board.raspberrypi.pico import *
 
+elif (
+    detector.board.RASPBERRY_PI_4B
+    or detector.board.RASPBERRY_PI_CM4
+    or detector.board.RASPBERRY_PI_400
+):
+    from adafruit_blinka.board.raspberrypi.raspi_4b import *
+
 elif detector.board.any_raspberry_pi_40_pin:
     from adafruit_blinka.board.raspberrypi.raspi_40pin import *
 
@@ -75,6 +82,9 @@ elif board_id == ap_board.BEAGLEBONE_BLACK:
 elif board_id == ap_board.BEAGLEBONE_GREEN:
     from adafruit_blinka.board.beagleboard.beaglebone_black import *
 
+elif board_id == ap_board.BEAGLEBONE_GREEN_GATEWAY:
+    from adafruit_blinka.board.beagleboard.beaglebone_black import *
+
 elif board_id == ap_board.BEAGLEBONE_BLACK_INDUSTRIAL:
     from adafruit_blinka.board.beagleboard.beaglebone_black import *
 
@@ -126,6 +136,9 @@ elif board_id == ap_board.ORANGE_PI_ZERO_PLUS:
 elif board_id == ap_board.ORANGE_PI_ZERO_2:
     from adafruit_blinka.board.orangepi.orangepizero2 import *
 
+elif board_id == ap_board.ORANGE_PI_3:
+    from adafruit_blinka.board.orangepi.orangepi3 import *
+
 elif board_id == ap_board.BANANA_PI_M2_ZERO:
     from adafruit_blinka.board.bananapi.bpim2zero import *
 
@@ -222,6 +235,12 @@ elif board_id == ap_board.UDOO_X86:
 elif board_id == ap_board.STM32MP157C_DK2:
     from adafruit_blinka.board.stm32.stm32mp157c_dk2 import *
 
+elif board_id == ap_board.OSD32MP1_RED:
+    from adafruit_blinka.board.stm32.osd32mp1_red import *
+
+elif board_id == ap_board.OSD32MP1_BRK:
+    from adafruit_blinka.board.stm32.osd32mp1_brk import *
+
 elif board_id == ap_board.LUBANCAT_IMX6ULL:
     from adafruit_blinka.board.lubancat.lubancat_imx6ull import *
 
@@ -234,6 +253,9 @@ elif board_id == ap_board.NANOPI_NEO_AIR:
 elif board_id == ap_board.NANOPI_DUO2:
     from adafruit_blinka.board.nanopi.duo2 import *
 
+elif board_id == ap_board.NANOPI_NEO:
+    from adafruit_blinka.board.nanopi.neo import *
+
 elif board_id == ap_board.PICO_U2IF:
     from adafruit_blinka.board.pico_u2if import *
 
